#
# Copyright 2020 VMware, Inc.  All rights reserved.
#
# This script implements installation check of features.
#
# The result of the script is:
#    yes - feature is installed
#    no - feature is not installed
#    unknown - can't get installation status for feature
#

import sqlite3 as sqlite
import sys

# Optional feature list supported on Linux client
installation_list = {
   "USB": "usbEnable",
   "SmartCard": "smartcardEnable",
   "RTAV": "rtavEnable",
   "CDR": "tsdrEnable",
   "TSMMR": "mmrEnable",
   "PrintRedir": "vmipEnable",
   "ScannerRedirection": "scannerEnable",
   "SerialPortRedirection": "serialportEnable"
}

dbfile = "/etc/vmware-installer-horizon/database"
feature = sys.argv[1]

if not feature in installation_list:
   print('unknown')
   sys.exit(1)

# Connect to database store installation status
try:
   db = sqlite.connect(dbfile, timeout=0, check_same_thread=False)
   db.row_factory = sqlite.Row
except sqlite.OperationalError:
   sys.exit(1)

# Query installation status in database
switch = installation_list[feature]

res = db.execute('SELECT value FROM settings WHERE key=?', (switch,));
row = res.fetchone()
value = row and row['value']

# Output installation check result
if value:
   print(value)
else:
   print('unknown')
